@@ -1,18 +1,16 @@
 import json
 from pathlib import Path
 
-from fps.hooks import register_router  # type: ignore
 import retrolab  # type: ignore
 from fastapi import APIRouter, Depends
 from fastapi.responses import HTMLResponse
 from fastapi.staticfiles import StaticFiles
-
+from fps.hooks import register_router  # type: ignore
 from fps_auth.backends import current_user  # type: ignore
-from fps_auth.models import User  # type: ignore
 from fps_auth.config import get_auth_config  # type: ignore
-
-from fps_lab.routes import init_router  # type: ignore
+from fps_auth.models import UserRead  # type: ignore
 from fps_lab.config import get_lab_config  # type: ignore
+from fps_lab.routes import init_router  # type: ignore
 from fps_lab.utils import get_federated_extensions  # type: ignore
 
 router = APIRouter()
@@ -46,7 +44,7 @@ retro_federated_extensions = [
 
 @router.get("/retro/tree", response_class=HTMLResponse)
 async def get_tree(
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
@@ -56,7 +54,7 @@ async def get_tree(
 @router.get("/retro/notebooks/{path:path}", response_class=HTMLResponse)
 async def get_notebook(
     path,
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
@@ -66,7 +64,7 @@ async def get_notebook(
 @router.get("/retro/edit/{path:path}", response_class=HTMLResponse)
 async def edit_file(
     path,
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
@@ -76,7 +74,7 @@ async def edit_file(
 @router.get("/retro/consoles/{path:path}", response_class=HTMLResponse)
 async def get_console(
     path,
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
@@ -86,7 +84,7 @@ async def get_console(
 @router.get("/retro/terminals/{name}", response_class=HTMLResponse)
 async def get_terminal(
     name: str,
-    user: User = Depends(current_user),
+    user: UserRead = Depends(current_user),
     lab_config=Depends(get_lab_config),
     auth_config=Depends(get_auth_config),
 ):
